#!/bin/sh

# Config
run_count=100

# Init Stats
let run_stat_good=0
let run_stat_bad=0

# Prepare logs directory
run_log_dir="logs-$(date +%F-%T | tr ':' '-')"
mkdir $run_log_dir

# Link "current" to the new logs directory
rm -f current
ln -s $run_log_dir current

# OpenMPI version
echo
mpirun --version

# Banner
echo
echo "** Run for $run_count times ... **"
echo
echo "Legend: RC = Exit code (0 -> NORMAL, 2 -> SIGPIPE)"
echo "        FC = Number of processes which print \"all done...\""
echo

# Run n times under GDB
for i in $(seq 1 $run_count); do
    run_log_file=$run_log_dir/run-$i-mpirun-gdb.log 
    echo -n "Run $i ... "
    gdb -x mpirun.gdb --args mpirun "$@" > $run_log_file 2>&1
    run_error=$?
    echo -n "RC=$run_error "
    run_finish_count=$(grep "all done..." $run_log_file | wc -l)
    echo -n "FC=$run_finish_count "
    if [ $run_error -eq 0 ]; then
        let "run_stat_good += 1"
        echo
    else
        let "run_stat_bad += 1"
        echo "($run_log_file)"
    fi
done

# Print Stats
echo
echo "** Finished **"
echo
echo "Good: $run_stat_good"
echo " Bad: $run_stat_bad"

